@@ -9,7 +9,7 @@ use Carp;
 use List::Util qw(first);
 use WebService::Linode::Base;
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 our @ISA     = ("WebService::Linode::Base");
 our $AUTOLOAD;
 
@@ -151,7 +151,9 @@ my %validation = (
         ],
     },
     test => { echo => [ [], [] ], },
-    user => { getapikey => [ [ 'password', 'username' ], [] ], },
+    user => {
+        getapikey => [ [qw( password username )], [qw( expires label token )] ],
+    },
 );
 
 sub AUTOLOAD {
@@ -1239,6 +1241,18 @@ Required Parameters:
 
 =back
 
+Optional Parameters:
+
+=over 4
+
+=item * expires
+
+=item * label
+
+=item * token
+
+=back
+
 =head1 AUTHORS
 
 =over
